@@ -170,7 +170,7 @@ class BoundaryPair(BoundaryAxisBase):
                     raise ValueError(f'Data items {data_copy.keys()} were not '
                                      'used.')
             else:
-                # one condition for low and high
+                # one condition for both sides
                 low = BCBase.from_data(grid, axis, upper=False, data=data,
                                        rank=rank)
                 high = BCBase.from_data(grid, axis, upper=True, data=data,
@@ -223,7 +223,7 @@ class BoundaryPair(BoundaryAxisBase):
             raise RuntimeError('Incompatible boundaries')
 
         # check whether both sides have no-flux conditions        
-        no_flux = all(isinstance(b, NeumannBC) and b.value == 0
+        no_flux = all(isinstance(b, NeumannBC) and np.all(b.value == 0)
                       for b in [self.low, self.high])
         if no_flux:
             return {'mode': 'reflect'}
