@@ -81,8 +81,8 @@ class CylindricalGrid(GridBase):  # lgtm [py/missing-equals]
         if len(bounds_z) != 2:
             raise ValueError('Lower and upper value of the axial coordinate '
                              'must be specified')
-        self._periodic_z: bool = periodic_z
-        self.periodic = [False, periodic_z]
+        self._periodic_z: bool = bool(periodic_z)  # might cast from np.bool_
+        self.periodic = [False, self._periodic_z]
 
         # radial discretization
         dr = radius / self.shape[0]
@@ -474,13 +474,17 @@ class CylindricalGrid(GridBase):  # lgtm [py/missing-equals]
 
 
     @fill_in_docstring
-    def get_boundary_conditions(self, bc='natural') -> "Boundaries":
+    def get_boundary_conditions(self, bc='natural', rank: int = 0) \
+            -> "Boundaries":
         """ constructs boundary conditions from a flexible data format
         
         Args:
             bc (str or list or tuple or dict):
                 The boundary conditions applied to the field.
                 {ARG_BOUNDARIES}  
+            rank (int):
+                The tensorial rank of the value associated with the boundary
+                conditions.
 
         Raises:
             ValueError: If the data given in `bc` cannot be read
@@ -488,7 +492,7 @@ class CylindricalGrid(GridBase):  # lgtm [py/missing-equals]
                 periodic axes of the grid. 
         """
         from .boundaries import Boundaries  # @Reimport
-        return Boundaries.from_data(self, bc)
+        return Boundaries.from_data(self, bc, rank=rank)
     
     
     
@@ -523,7 +527,17 @@ class CylindricalGrid(GridBase):  # lgtm [py/missing-equals]
 
     def get_subgrid(self, indices: Sequence[int]) \
             -> Union["CartesianGrid", "PolarGrid"]:
-        """ return a subgrid of only the specified axes """
+        """ return a subgrid of only the specified axes
+        
+        
+        Args:
+            indices (list):
+                Indices indicating the axes that are retained in the subgrid
+                
+        Returns:
+            :class:`~pde.grids.cartesian.CartesianGrid` or 
+            :class:`~pde.grids.spherical.PolarGrid`: The subgrid
+        """
         if len(indices) != 1:
             raise ValueError(f'Can only get sub-grid for one axis.')
         
