@@ -23,7 +23,13 @@ if TYPE_CHECKING:
 
 
 class PDEBase(metaclass=ABCMeta):
-    """ base class for solving partial differential equations """
+    """ base class for solving partial differential equations
+    
+    Custom PDEs can be implemented by specifying their evolution rate. In the
+    simple case of deterministic PDEs, the methods
+    :meth:`PDEBase.evolution_rate` and :meth:`PDEBase._make_pde_rhs_numba` need 
+    to be overwritten for the `numpy` and `numba` backend, respectively.
+    """
 
     check_implementation: bool = True
     """ bool: Flag determining whether (some) numba-compiled functions should be
@@ -64,6 +70,25 @@ class PDEBase(metaclass=ABCMeta):
         """
         # check for self.noise, in case __init__ is not called in a subclass
         return hasattr(self, 'noise') and self.noise != 0
+  
+
+    def make_modify_after_step(self) -> Callable:
+        """ returns a function that can be called to modify a state
+        
+        This function is applied to the state after each integration step when
+        an explicit stepper is used. The default behavior is to not change the
+        state.
+        
+        Returns:
+            Function that can be applied to a state to modify it and which
+            returns a measure for the corrections applied to the state 
+        """
+        
+        def modify_after_step(state: np.ndarray):
+            """ no-op function """
+            pass
+
+        return modify_after_step
 
 
     @abstractmethod
@@ -370,4 +395,4 @@ class PDEBase(metaclass=ABCMeta):
             return final_state, info
         else: 
             return final_state
-                
\ No newline at end of file
+                
