@@ -4,6 +4,7 @@ Tools for plotting and controlling plot output using context managers
 .. autosummary::
    :nosignatures:
 
+   add_scaled_colorbar
    finalize_plot
    disable_interactive
    plot_on_axes
@@ -24,10 +25,6 @@ import logging
 import warnings
 from typing import Type, Dict, Tuple, Any, TYPE_CHECKING  # @UnusedImport
 
-import matplotlib as mpl
-import matplotlib.pyplot as plt
-import matplotlib.axes as mpl_axes
-
 from ..tools.docstrings import replace_in_docstring
 
 if TYPE_CHECKING:
@@ -35,6 +32,38 @@ if TYPE_CHECKING:
 
  
 
+def add_scaled_colorbar(axes_image,
+                        aspect: float = 20,
+                        pad_fraction: float = 0.5,
+                        **kwargs):
+    """ add a vertical color bar to an image plot
+    
+    The height of the colorbar is now adjusted to the plot, so that the width
+    determined by `aspect` is now given relative to the height. Moreover, the
+    gap between the colorbar and the plot is now given in units of the fraction
+    of the width by `pad_fraction`. 
+
+    Inspired by https://stackoverflow.com/a/33505522/932593
+    
+    Args:
+        axes_image: object returned from :meth:`matplotlib.pyplot.imshow`
+        ax (:class:`matplotlib.axes.Axes`): the current figure axes
+        aspect (float): the target aspect ratio of the colorbar
+        pad_fraction (float): Width of the gap between colorbar and image
+        **kwargs: Additional parameters are passed to colorbar call
+
+    Returns:
+        the result of the colorbar call
+    """
+    from mpl_toolkits import axes_grid1
+    divider = axes_grid1.make_axes_locatable(axes_image.axes)
+    width = axes_grid1.axes_size.AxesY(axes_image.axes, aspect=1./aspect)
+    pad = axes_grid1.axes_size.Fraction(pad_fraction, width)
+    cax = divider.append_axes("right", size=width, pad=pad)
+    return axes_image.axes.figure.colorbar(axes_image, cax=cax, **kwargs)            
+       
+
+
 class nested_plotting_check():
     """ context manager that checks whether it is the root plotting call
     
@@ -57,13 +86,14 @@ class nested_plotting_check():
     
     
     def __enter__(self):
-        self.is_nested = nested_plotting_check._is_plotting
-        nested_plotting_check._is_plotting = True
+        self.is_nested = self.__class__._is_plotting
+        self.__class__._is_plotting = True
         return not self.is_nested
     
+    
     def __exit__(self, *exc):
         if not self.is_nested:
-            nested_plotting_check._is_plotting = False
+            self.__class__._is_plotting = False
 
 
 
@@ -90,6 +120,8 @@ def finalize_plot(fig_or_ax=None,
     Returns:
         tuple: The figure and the axes that were used to finalize the plot
     """
+    import matplotlib.pyplot as plt
+    
     # Deprecated this method on 2020-06-13
     warnings.warn("finalize_plot() method is deprecated. Use the decorators "
                   "plot_on_axes or plot_on_figure to control plots instead.",
@@ -127,6 +159,8 @@ def disable_interactive():
     This context manager restores the previous state after it is done. Details
     of the interactive mode are described in :func:`matplotlib.interactive`.
     """
+    import matplotlib.pyplot as plt
+
     if plt.isinteractive():
         # interactive mode is enabled => disable it temporarily
         plt.interactive(False) 
@@ -234,6 +268,8 @@ def plot_on_axes(wrapped=None, update_method=None):
         """
         # Note on docstring: This docstring replaces the token {PLOT_ARGS} in 
         # the wrapped function
+        import matplotlib as mpl
+        import matplotlib.pyplot as plt
         
         # some logic to check for nested plotting calls:
         with nested_plotting_check() as is_outermost_plot_call:
@@ -362,7 +398,14 @@ def plot_on_figure(wrapped=None, update_method=None):
         return functools.partial(plot_on_figure, update_method=update_method)    
     
     
-    def wrapper(*args, **kwargs):
+    def wrapper(*args,
+                title: str = None,
+                constrained_layout: bool = True,
+                filename: str = None,
+                action: str = 'auto',
+                fig_style: Dict[str, Any] = None,
+                fig=None,
+                **kwargs):
         """
         title (str):
             Title of the plot. If omitted, the title might be chosen
@@ -390,13 +433,8 @@ def plot_on_figure(wrapped=None, update_method=None):
         """
         # Note on docstring: This docstring replaces the token {PLOT_ARGS} in 
         # the wrapped function
-        
-        title = kwargs.pop('title', None)
-        constrained_layout = kwargs.pop('constrained_layout', True)
-        filename = kwargs.pop('filename', None)
-        action = kwargs.pop('action', 'auto')
-        fig_style = kwargs.pop('fig_style', {})
-        fig = kwargs.pop('fig', None)
+        import matplotlib as mpl
+        import matplotlib.pyplot as plt
         
         # some logic to check for nested plotting calls:
         with nested_plotting_check() as is_outermost_plot_call:
@@ -506,12 +544,14 @@ class PlottingContextBase(object):
     def __enter__(self):
         # start the plotting process
         if self.fig is not None:
+            import matplotlib.pyplot as plt
             plt.figure(self.fig.number)
     
 
     def __exit__(self, *exc): 
         if self.initial_plot or not self.supports_update:
             # recreate the entire figure
+            import matplotlib.pyplot as plt
             self.fig = plt.gcf()
             if len(self.fig.axes) == 0:
                 # The figure seems to be empty, which must be a mistake
@@ -539,6 +579,7 @@ class PlottingContextBase(object):
         """ close the plot """
         # close matplotlib figure
         if self.fig is not None:
+            import matplotlib.pyplot as plt
             plt.close(self.fig)
 
 
@@ -560,12 +601,15 @@ class BasicPlottingContext(PlottingContextBase):
             show (bool):
                 Flag determining whether plots are actually shown
         """
+        import matplotlib.axes as mpl_axes
+        import matplotlib.figure as mpl_figure
+        
         super().__init__(title=title, show=show)
         
         # determine which figure to modify
         if isinstance(fig_or_ax, mpl_axes.Axes):
             self.fig = fig_or_ax.get_figure()  # assume that axes are given
-        elif isinstance(fig_or_ax, mpl.figure.Figure):
+        elif isinstance(fig_or_ax, mpl_figure.Figure):
             self.fig = fig_or_ax
     
 
@@ -576,6 +620,7 @@ class BasicPlottingContext(PlottingContextBase):
             with warnings.catch_warnings():
                 warnings.simplefilter("ignore")
                 # add a small pause to allow the GUI to run it's event loop
+                import matplotlib.pyplot as plt
                 plt.pause(1e-3)
 
 
@@ -594,6 +639,7 @@ class JupyterPlottingContext(PlottingContextBase):
         
         if self.initial_plot:
             # close all previous plots
+            import matplotlib.pyplot as plt
             plt.close('all')
             
             # create output widget for capturing all plotting
@@ -608,6 +654,7 @@ class JupyterPlottingContext(PlottingContextBase):
     
     
     def __exit__(self, *exc):
+        import matplotlib.pyplot as plt
         # finalize plot
         super().__exit__(*exc)
         
@@ -655,6 +702,10 @@ def get_plotting_context(context=None,
     Returns:
         :class:`PlottingContextBase`: The plotting context
     """
+    import matplotlib as mpl
+    import matplotlib.axes as mpl_axes
+    import matplotlib.figure as mpl_figure
+    
     if context is None:
         # figure out whether plots are shown in jupyter notebook
         
@@ -680,7 +731,7 @@ def get_plotting_context(context=None,
         context.show = show
         return context
     
-    elif isinstance(context, (mpl_axes.Axes, mpl.figure.Figure)):
+    elif isinstance(context, (mpl_axes.Axes, mpl_figure.Figure)):
         # create a basic context based on the given axes or figure
         return BasicPlottingContext(fig_or_ax=context, title=title, show=show)
     
